@@ -1,11 +1,10 @@
-#include <QApplication>
+#include <QCoreApplication>
 #include "%{APPNAME}.h"
 
 
 int main(int argc, char** argv)
 {
-    QApplication app(argc, argv);
+    QCoreApplication app(argc, argv);
     %{APPNAMEID} %{APPNAMELC};
-    %{APPNAMELC}.show();
     return app.exec();
 }
